package com.example.pharmacy.frontEnd;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.SeekBar;
import android.widget.Spinner;
import android.widget.Switch;
import android.widget.Toast;

import java.io.File;
import java.io.FileOutputStream;

/**
 * Created by pharmacy on 16/02/2018.
 */

public class AdvancedSettings extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.advanced_settings);
        setUpButtons();
        retrieveSettings();
    }


    @Override
    protected void onStop(){
        super.onStop();
        saveSharedPreferenceData();
    }

    private void retrieveSettings(){
        SharedPreferences shared = this.getSharedPreferences(getString(R.string.preference_file_key), Context.MODE_PRIVATE);
        ((Spinner)findViewById(R.id.PeriodSpinner)).setSelection(shared.getInt(getString(R.string.led_period_pos), 0));
        ((Spinner)findViewById(R.id.ColourSpinner)).setSelection(shared.getInt(getString(R.string.led_colour_pos), 0));
    }

    private void setUpButtons(){
        ImageButton back = (ImageButton)findViewById(R.id.back);
        back.bringToFront();
        back.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                //Saved in shared preferences, add integer resource for default values to be used when obtaining from shared preferences.
                saveSharedPreferenceData();

                Intent intent = new Intent(view.getContext(), Settings.class);
                displaySavedToast(view);
                startActivity(intent);
            }
        });
        final Button upload = findViewById(R.id.upload);
        upload.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                //DO UPLOAD THINGS HERE
                File file = SaveFile.zipFiles(view.getContext());
                Intent sendIntent = new Intent(Intent.ACTION_SEND);
                if(file.exists() && (file != null)){
                    sendIntent.setType("notificationapp/zip");
                    sendIntent.putExtra(Intent.EXTRA_STREAM, Uri.parse("file://"+file.getAbsolutePath()));
                    sendIntent.putExtra(Intent.EXTRA_SUBJECT,"Sharing File...");
                    sendIntent.putExtra(Intent.EXTRA_TEXT, "Sharing File...");
                    startActivity(Intent.createChooser(sendIntent, "Share File"));
                }
            }
        });
        populateSpinners();
    }


    private void populateSpinners(){
        Spinner spinnerP =  findViewById(R.id.PeriodSpinner);
        ArrayAdapter<CharSequence> adapterP = ArrayAdapter.createFromResource(this, R.array.LED_periods, android.R.layout.simple_spinner_dropdown_item);
        adapterP.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinnerP.setAdapter(adapterP);
        Spinner spinnerC = findViewById(R.id.ColourSpinner);
        ArrayAdapter<CharSequence> adapterC = ArrayAdapter.createFromResource(this, R.array.LED_colours, android.R.layout.simple_spinner_dropdown_item);
        adapterC.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinnerC.setAdapter(adapterC);

    }
    private void displaySavedToast(View view){
        Toast saved = Toast.makeText(view.getContext(), R.string.settings_saved,Toast.LENGTH_SHORT);
        saved.show();
    }

    private void saveSharedPreferenceData(){
        SharedPreferences sharedPref = this.getSharedPreferences(getString(R.string.preference_file_key), Context.MODE_PRIVATE);
        int spinnerPPos = ((Spinner)findViewById(R.id.PeriodSpinner)).getSelectedItemPosition();
        int notifyGap = Integer.parseInt(((Spinner)findViewById(R.id.PeriodSpinner)).getSelectedItem().toString());
        int spinnerCPos = ((Spinner)findViewById(R.id.ColourSpinner)).getSelectedItemPosition();
        String colour = ((Spinner)findViewById(R.id.ColourSpinner)).getSelectedItem().toString();
        SharedPreferences.Editor editor = sharedPref.edit();
        editor.putInt(getString(R.string.led_period_pos), spinnerPPos);
        editor.putInt(getString(R.string.led_period), notifyGap);
        editor.putInt(getString(R.string.led_colour_pos), spinnerCPos);
        editor.putString(getString(R.string.led_colour), colour);
        editor.commit();
    }
}

